==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeHttpGetFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeHttpGetFluent<A extends ReadinessProbeHttpGetFluent<A>> extends BaseFluent<A>{
  public ReadinessProbeHttpGetFluent() {
  }
  public ReadinessProbeHttpGetFluent(ReadinessProbeHttpGet instance) {
    instance = (instance != null ? instance : new ReadinessProbeHttpGet());

    if (instance != null) {
      this.withHttpGet(instance.getHttpGet());
      this.withHttpGet(instance.getHttpGet());
    }
  }
  private HTTPHealthCheckConfigBuilder httpGet;
  public HTTPHealthCheckConfig buildHttpGet() {
    return this.httpGet!=null ?this.httpGet.build():null;
  }
  public A withHttpGet(HTTPHealthCheckConfig httpGet) {
    _visitables.get("httpGet").remove(this.httpGet);
    if (httpGet!=null){ this.httpGet= new HTTPHealthCheckConfigBuilder(httpGet); _visitables.get("httpGet").add(this.httpGet);} else { this.httpGet = null; _visitables.get("httpGet").remove(this.httpGet); } return (A) this;
  }
  public boolean hasHttpGet() {
    return this.httpGet != null;
  }
  public HttpGetNested<A> withNewHttpGet() {
    return new HttpGetNested(null);
  }
  public HttpGetNested<A> withNewHttpGetLike(HTTPHealthCheckConfig item) {
    return new HttpGetNested(item);
  }
  public HttpGetNested<A> editHttpGet() {
    return withNewHttpGetLike(java.util.Optional.ofNullable(buildHttpGet()).orElse(null));
  }
  public HttpGetNested<A> editOrNewHttpGet() {
    return withNewHttpGetLike(java.util.Optional.ofNullable(buildHttpGet()).orElse(new HTTPHealthCheckConfigBuilder().build()));
  }
  public HttpGetNested<A> editOrNewHttpGetLike(HTTPHealthCheckConfig item) {
    return withNewHttpGetLike(java.util.Optional.ofNullable(buildHttpGet()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeHttpGetFluent that = (ReadinessProbeHttpGetFluent) o;
    if (!java.util.Objects.equals(httpGet, that.httpGet)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpGet,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpGet != null) { sb.append("httpGet:"); sb.append(httpGet); }
    sb.append("}");
    return sb.toString();
  }
  public class HttpGetNested<N> extends HTTPHealthCheckConfigFluent<HttpGetNested<N>> implements Nested<N>{
    HttpGetNested(HTTPHealthCheckConfig item) {
      this.builder = new HTTPHealthCheckConfigBuilder(this, item);
    }
    HTTPHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeHttpGetFluent.this.withHttpGet(builder.build());
    }
    public N endHttpGet() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeHttpGetFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ReadinessProbeHttpGetFluent<A extends ReadinessProbeHttpGetFluent<A>> extends BaseFluent<A>{
  public ReadinessProbeHttpGetFluent() {
  }
  
  public ReadinessProbeHttpGetFluent(ReadinessProbeHttpGet instance) {
    this.copyInstance(instance);
  }
  private HTTPHealthCheckConfigBuilder httpGet;
  
  protected void copyInstance(ReadinessProbeHttpGet instance) {
    instance = (instance != null ? instance : new ReadinessProbeHttpGet());
  
    if (instance != null) {
        this.withHttpGet(instance.getHttpGet());
        this.withHttpGet(instance.getHttpGet());
      }
  }
  
  public HTTPHealthCheckConfig buildHttpGet() {
    return this.httpGet!=null ?this.httpGet.build():null;
  }
  
  public A withHttpGet(HTTPHealthCheckConfig httpGet) {
    _visitables.get("httpGet").remove(this.httpGet);
    if (httpGet!=null){ this.httpGet= new HTTPHealthCheckConfigBuilder(httpGet); _visitables.get("httpGet").add(this.httpGet);} else { this.httpGet = null; _visitables.get("httpGet").remove(this.httpGet); } return (A) this;
  }
  
  public boolean hasHttpGet() {
    return this.httpGet != null;
  }
  
  public HttpGetNested<A> withNewHttpGet() {
    return new HttpGetNested(null);
  }
  
  public HttpGetNested<A> withNewHttpGetLike(HTTPHealthCheckConfig item) {
    return new HttpGetNested(item);
  }
  
  public HttpGetNested<A> editHttpGet() {
    return withNewHttpGetLike(java.util.Optional.ofNullable(buildHttpGet()).orElse(null));
  }
  
  public HttpGetNested<A> editOrNewHttpGet() {
    return withNewHttpGetLike(java.util.Optional.ofNullable(buildHttpGet()).orElse(new HTTPHealthCheckConfigBuilder().build()));
  }
  
  public HttpGetNested<A> editOrNewHttpGetLike(HTTPHealthCheckConfig item) {
    return withNewHttpGetLike(java.util.Optional.ofNullable(buildHttpGet()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeHttpGetFluent that = (ReadinessProbeHttpGetFluent) o;
    if (!java.util.Objects.equals(httpGet, that.httpGet)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(httpGet,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpGet != null) { sb.append("httpGet:"); sb.append(httpGet); }
    sb.append("}");
    return sb.toString();
  }
  public class HttpGetNested<N> extends HTTPHealthCheckConfigFluent<HttpGetNested<N>> implements Nested<N>{
    HttpGetNested(HTTPHealthCheckConfig item) {
      this.builder = new HTTPHealthCheckConfigBuilder(this, item);
    }
    HTTPHealthCheckConfigBuilder builder;
    
    public N and() {
      return (N) ReadinessProbeHttpGetFluent.this.withHttpGet(builder.build());
    }
    
    public N endHttpGet() {
      return and();
    }
    
  
  }

}
